==> globalaccelerator-2.17.172-sources.jar: software/amazon/awssdk/services/globalaccelerator/paginators/ListListenersIterable.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.globalaccelerator.paginators;

import java.util.Collections;
import java.util.Iterator;
import java.util.function.Function;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.pagination.sync.PaginatedItemsIterable;
import software.amazon.awssdk.core.pagination.sync.PaginatedResponsesIterator;
import software.amazon.awssdk.core.pagination.sync.SdkIterable;
import software.amazon.awssdk.core.pagination.sync.SyncPageFetcher;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.globalaccelerator.GlobalAcceleratorClient;
import software.amazon.awssdk.services.globalaccelerator.model.ListListenersRequest;
import software.amazon.awssdk.services.globalaccelerator.model.ListListenersResponse;
import software.amazon.awssdk.services.globalaccelerator.model.Listener;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.globalaccelerator.GlobalAcceleratorClient#listListenersPaginator(software.amazon.awssdk.services.globalaccelerator.model.ListListenersRequest)}
 * operation which is a paginated operation. This class is an iterable of
 * {@link software.amazon.awssdk.services.globalaccelerator.model.ListListenersResponse} that can be used to iterate
 * through all the response pages of the operation.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. As you iterate through the iterable, SDK will start lazily
 * loading response pages by making service calls until there are no pages left or your iteration stops. If there are
 * errors in your request, you will see the failures only after you start iterating through the iterable.
 * </p>
 *
 * <p>
 * The following are few ways to iterate through the response pages:
 * </p>
 * 1) Using a Stream
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.globalaccelerator.paginators.ListListenersIterable responses = client.listListenersPaginator(request);
 * responses.stream().forEach(....);
 * }
 * </pre>
 *
 * 2) Using For loop
 * 
 * <pre>
 * {
 *     &#064;code
 *     software.amazon.awssdk.services.globalaccelerator.paginators.ListListenersIterable responses = client
 *             .listListenersPaginator(request);
 *     for (software.amazon.awssdk.services.globalaccelerator.model.ListListenersResponse response : responses) {
 *         // do something;
 *     }
 * }
 * </pre>
 *
 * 3) Use iterator directly
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.globalaccelerator.paginators.ListListenersIterable responses = client.listListenersPaginator(request);
 * responses.iterator().forEachRemaining(....);
 * }
 * </pre>
 * <p>
 * <b>Please notice that the configuration of MaxResults won't limit the number of results you get with the paginator.
 * It only limits the number of results in each page.</b>
 * </p>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #listListeners(software.amazon.awssdk.services.globalaccelerator.model.ListListenersRequest)} operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class ListListenersIterable implements SdkIterable<ListListenersResponse> {
    private final GlobalAcceleratorClient client;

    private final ListListenersRequest firstRequest;

    private final SyncPageFetcher nextPageFetcher;

    public ListListenersIterable(GlobalAcceleratorClient client, ListListenersRequest firstRequest) {
        this.client = client;
        this.firstRequest = firstRequest;
        this.nextPageFetcher = new ListListenersResponseFetcher();
    }

    @Override
    public Iterator<ListListenersResponse> iterator() {
        return PaginatedResponsesIterator.builder().nextPageFetcher(nextPageFetcher).build();
    }

    /**
     * Returns an iterable to iterate through the paginated {@link ListListenersResponse#listeners()} member. The
     * returned iterable is used to iterate through the results across all response pages and not a single page.
     *
     * This method is useful if you are interested in iterating over the paginated member in the response pages instead
     * of the top level pages. Similar to iteration over pages, this method internally makes service calls to get the
     * next list of results until the iteration stops or there are no more results.
     */
    public final SdkIterable<Listener> listeners() {
        Function<ListListenersResponse, Iterator<Listener>> getIterator = response -> {
            if (response != null && response.listeners() != null) {
                return response.listeners().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsIterable.<ListListenersResponse, Listener> builder().pagesIterable(this)
                .itemIteratorFunction(getIterator).build();
    }

    private class ListListenersResponseFetcher implements SyncPageFetcher<ListListenersResponse> {
        @Override
        public boolean hasNextPage(ListListenersResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.nextToken());
        }

        @Override
        public ListListenersResponse nextPage(ListListenersResponse previousPage) {
            if (previousPage == null) {
                return client.listListeners(firstRequest);
            }
            return client.listListeners(firstRequest.toBuilder().nextToken(previousPage.nextToken()).build());
        }
    }
}

==> globalaccelerator-2.22.2-sources.jar: software/amazon/awssdk/services/globalaccelerator/paginators/ListListenersIterable.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.globalaccelerator.paginators;

import java.util.Collections;
import java.util.Iterator;
import java.util.function.Function;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.pagination.sync.PaginatedItemsIterable;
import software.amazon.awssdk.core.pagination.sync.PaginatedResponsesIterator;
import software.amazon.awssdk.core.pagination.sync.SdkIterable;
import software.amazon.awssdk.core.pagination.sync.SyncPageFetcher;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.globalaccelerator.GlobalAcceleratorClient;
import software.amazon.awssdk.services.globalaccelerator.internal.UserAgentUtils;
import software.amazon.awssdk.services.globalaccelerator.model.ListListenersRequest;
import software.amazon.awssdk.services.globalaccelerator.model.ListListenersResponse;
import software.amazon.awssdk.services.globalaccelerator.model.Listener;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.globalaccelerator.GlobalAcceleratorClient#listListenersPaginator(software.amazon.awssdk.services.globalaccelerator.model.ListListenersRequest)}
 * operation which is a paginated operation. This class is an iterable of
 * {@link software.amazon.awssdk.services.globalaccelerator.model.ListListenersResponse} that can be used to iterate
 * through all the response pages of the operation.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. As you iterate through the iterable, SDK will start lazily
 * loading response pages by making service calls until there are no pages left or your iteration stops. If there are
 * errors in your request, you will see the failures only after you start iterating through the iterable.
 * </p>
 *
 * <p>
 * The following are few ways to iterate through the response pages:
 * </p>
 * 1) Using a Stream
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.globalaccelerator.paginators.ListListenersIterable responses = client.listListenersPaginator(request);
 * responses.stream().forEach(....);
 * }
 * </pre>
 *
 * 2) Using For loop
 * 
 * <pre>
 * {
 *     &#064;code
 *     software.amazon.awssdk.services.globalaccelerator.paginators.ListListenersIterable responses = client
 *             .listListenersPaginator(request);
 *     for (software.amazon.awssdk.services.globalaccelerator.model.ListListenersResponse response : responses) {
 *         // do something;
 *     }
 * }
 * </pre>
 *
 * 3) Use iterator directly
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.globalaccelerator.paginators.ListListenersIterable responses = client.listListenersPaginator(request);
 * responses.iterator().forEachRemaining(....);
 * }
 * </pre>
 * <p>
 * <b>Please notice that the configuration of MaxResults won't limit the number of results you get with the paginator.
 * It only limits the number of results in each page.</b>
 * </p>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #listListeners(software.amazon.awssdk.services.globalaccelerator.model.ListListenersRequest)} operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class ListListenersIterable implements SdkIterable<ListListenersResponse> {
    private final GlobalAcceleratorClient client;

    private final ListListenersRequest firstRequest;

    private final SyncPageFetcher nextPageFetcher;

    public ListListenersIterable(GlobalAcceleratorClient client, ListListenersRequest firstRequest) {
        this.client = client;
        this.firstRequest = UserAgentUtils.applyPaginatorUserAgent(firstRequest);
        this.nextPageFetcher = new ListListenersResponseFetcher();
    }

    @Override
    public Iterator<ListListenersResponse> iterator() {
        return PaginatedResponsesIterator.builder().nextPageFetcher(nextPageFetcher).build();
    }

    /**
     * Returns an iterable to iterate through the paginated {@link ListListenersResponse#listeners()} member. The
     * returned iterable is used to iterate through the results across all response pages and not a single page.
     *
     * This method is useful if you are interested in iterating over the paginated member in the response pages instead
     * of the top level pages. Similar to iteration over pages, this method internally makes service calls to get the
     * next list of results until the iteration stops or there are no more results.
     */
    public final SdkIterable<Listener> listeners() {
        Function<ListListenersResponse, Iterator<Listener>> getIterator = response -> {
            if (response != null && response.listeners() != null) {
                return response.listeners().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsIterable.<ListListenersResponse, Listener> builder().pagesIterable(this)
                .itemIteratorFunction(getIterator).build();
    }

    private class ListListenersResponseFetcher implements SyncPageFetcher<ListListenersResponse> {
        @Override
        public boolean hasNextPage(ListListenersResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.nextToken());
        }

        @Override
        public ListListenersResponse nextPage(ListListenersResponse previousPage) {
            if (previousPage == null) {
                return client.listListeners(firstRequest);
            }
            return client.listListeners(firstRequest.toBuilder().nextToken(previousPage.nextToken()).build());
        }
    }
}
